@@ -16,7 +16,9 @@ class RunCommandsTest(TestCase):
         self.watcher = Mock(name="somename", working_dir=working_dir)
 
     def cmd(self, command):
-        return "cd {} && {}".format(self.watcher.working_dir, command)
+        source = "source /home/application/apprc &&"
+        return "{} cd {} && {}".format(source, self.watcher.working_dir,
+                                       command)
 
     @patch("tsuru.hooks.load_config")
     @patch("subprocess.check_output")
